agentle.agents.whatsapp.models.downloaded\_media
================================================

.. automodule:: agentle.agents.whatsapp.models.downloaded_media

   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      ConfigDict
      DownloadedMedia
   